==> ZenTaoPMS.max2.2.php7.2_7.4.zip: zentaopms/module/baseline/lang/en.php <==
<?PHP
$lang->baseline->common         = 'Baseline';
$lang->baseline->name           = 'Title';
$lang->baseline->template       = 'Template';
$lang->baseline->catalog        = 'Catalog';
$lang->baseline->createTemplate = 'Create Template';
$lang->baseline->editTemplate   = 'Edit Template';
$lang->baseline->templateTitle  = 'Template Title';
$lang->baseline->templateType   = 'Template Type';
$lang->baseline->docType        = 'Document Type';
$lang->baseline->docContent     = 'Content';
$lang->baseline->url            = 'URL';
$lang->baseline->manageChild    = 'Manage Child';
$lang->baseline->addedBy        = 'AddedBy';
$lang->baseline->addedDate      = 'Added';
$lang->baseline->files          = 'Files';
$lang->baseline->view           = 'View';
$lang->baseline->editBook       = 'Edit Book';
$lang->baseline->manageBook     = 'Manage Book';
$lang->baseline->addCatalogTip  = 'No chapters yet.';
$lang->baseline->editArticle    = 'Edit Article';
$lang->baseline->articleView    = 'Article View';
$lang->baseline->editChapter    = 'Edit Chapter';
$lang->baseline->chapter        = 'Chapter';
$lang->baseline->chapterName    = 'Chapter Title';
$lang->baseline->baseInfo       = 'Basic Information';
$lang->baseline->chapterType    = 'Data Source';
$lang->baseline->delete         = 'Delete';

$lang->baseline->docTypeList['html']      = 'HTML';
$lang->baseline->docTypeList['markdown']  = 'Markdown';
$lang->baseline->docTypeList['url']       = 'URL';
$lang->baseline->docTypeList['book']      = 'Wiki';

$lang->baseline->chapterTypeList['input']  = 'Manual Input';
$lang->baseline->chapterTypeList['system'] = 'System Data';

$lang->baseline->confirmDelete = 'Do you want to delete it?';

$lang->baseline->setting      = 'Setting';
$lang->baseline->version      = 'Version';
$lang->baseline->reviewer     = 'Reviewer';
$lang->baseline->padding      = 'Padding';
$lang->baseline->reviewerRole = 'Reviewer Role';

$lang->baseline->confirm[1] = 'Yes';
$lang->baseline->confirm[0] = 'No';

$lang->baseline->objectList['PP']   = 'Project Plan';
$lang->baseline->objectList['QAP']  = 'Quality Assurance Plan';
$lang->baseline->objectList['CMP']  = 'Configuration Management Plan';
$lang->baseline->objectList['ITP']  = 'Integration Test Plan';
$lang->baseline->objectList['URS']  = 'User Requirement Statement';
$lang->baseline->objectList['SRS']  = 'Software Requirements Specification';
$lang->baseline->objectList['HLDS'] = 'High Level Design Statement';
$lang->baseline->objectList['DDS']  = 'Detailed Design Statement';
$lang->baseline->objectList['Code'] = 'Code';
$lang->baseline->objectList['ITTC'] = 'Integrate Test Cases';
$lang->baseline->objectList['STP']  = 'System Test Plan';
$lang->baseline->objectList['STTC'] = 'System Test Cases';
$lang->baseline->objectList['UM']   = 'User Manual';

$lang->baseline->versionForm['0']     = '';
$lang->baseline->versionForm['date1'] = 'YMD';
$lang->baseline->versionForm['date2'] = 'Y-M-D';
$lang->baseline->versionForm['fixed'] = 'Fixed';
$lang->baseline->versionForm['user']  = 'User';

$lang->baseline->joint['']  = '';
$lang->baseline->joint['.'] = '.';
$lang->baseline->joint['-'] = '-';
$lang->baseline->joint['_'] = '_';

==> ZenTaoPMS.max2.7.php5.3_5.6.zip: zentaopms/module/baseline/lang/en.php <==
<?PHP
$lang->baseline->common         = 'Baseline';
$lang->baseline->name           = 'Title';
$lang->baseline->template       = 'Template';
$lang->baseline->catalog        = 'Catalog';
$lang->baseline->createTemplate = 'Create Template';
$lang->baseline->editTemplate   = 'Edit Template';
$lang->baseline->templateTitle  = 'Template Title';
$lang->baseline->templateType   = 'Template Type';
$lang->baseline->docType        = 'Document Type';
$lang->baseline->docContent     = 'Content';
$lang->baseline->url            = 'URL';
$lang->baseline->manageChild    = 'Manage Child';
$lang->baseline->addedBy        = 'AddedBy';
$lang->baseline->addedDate      = 'Added';
$lang->baseline->files          = 'Files';
$lang->baseline->view           = 'View';
$lang->baseline->editBook       = 'Edit Book';
$lang->baseline->manageBook     = 'Manage Book';
$lang->baseline->addCatalogTip  = 'No chapters yet.';
$lang->baseline->editArticle    = 'Edit Article';
$lang->baseline->articleView    = 'Article View';
$lang->baseline->editChapter    = 'Edit Chapter';
$lang->baseline->chapter        = 'Chapter';
$lang->baseline->chapterName    = 'Chapter Title';
$lang->baseline->baseInfo       = 'Basic Information';
$lang->baseline->chapterType    = 'Data Source';
$lang->baseline->delete         = 'Delete';

$lang->baseline->docTypeList['html']      = 'HTML';
$lang->baseline->docTypeList['markdown']  = 'Markdown';
$lang->baseline->docTypeList['url']       = 'URL';
$lang->baseline->docTypeList['book']      = 'Wiki';

$lang->baseline->chapterTypeList['input']  = 'Manual Input';
$lang->baseline->chapterTypeList['system'] = 'System Data';

$lang->baseline->confirmDelete = 'Do you want to delete it?';

$lang->baseline->setting      = 'Setting';
$lang->baseline->version      = 'Version';
$lang->baseline->reviewer     = 'Reviewer';
$lang->baseline->padding      = 'Padding';
$lang->baseline->reviewerRole = 'Reviewer Role';

$lang->baseline->confirm[1] = 'Yes';
$lang->baseline->confirm[0] = 'No';

$lang->baseline->objectList[''] = '';
$lang->baseline->objectList['PP']   = 'Project Plan';
$lang->baseline->objectList['QAP']  = 'Quality Assurance Plan';
$lang->baseline->objectList['CMP']  = 'Configuration Management Plan';
$lang->baseline->objectList['ITP']  = 'Integration Test Plan';
$lang->baseline->objectList['URS']  = 'User Requirement Statement';
$lang->baseline->objectList['SRS']  = 'Software Requirements Specification';
$lang->baseline->objectList['HLDS'] = 'High Level Design Statement';
$lang->baseline->objectList['DDS']  = 'Detailed Design Statement';
$lang->baseline->objectList['DBDS'] = 'Database Design Statement';
$lang->baseline->objectList['ADS']  = 'Interface Design Statement';
$lang->baseline->objectList['Code'] = 'Code';
$lang->baseline->objectList['ITTC'] = 'Integrate Test Cases';
$lang->baseline->objectList['STP']  = 'System Test Plan';
$lang->baseline->objectList['STTC'] = 'System Test Cases';
$lang->baseline->objectList['UM']   = 'User Manual';

$lang->baseline->versionForm['0']     = '';
$lang->baseline->versionForm['date1'] = 'YMD';
$lang->baseline->versionForm['date2'] = 'Y-M-D';
$lang->baseline->versionForm['fixed'] = 'Fixed';
$lang->baseline->versionForm['user']  = 'User';

$lang->baseline->joint['']  = '';
$lang->baseline->joint['.'] = '.';
$lang->baseline->joint['-'] = '-';
$lang->baseline->joint['_'] = '_';
